@@ -27,12 +27,18 @@ GBM <- function(N, ...)  UseMethod("GBM")
 
 GBM.default <- function(N =1000,M=1,x0=1,t0=0,T=1,Dt=NULL,theta=1,sigma=1,...)
              {
-    if (any(!is.numeric(x0) || x0 <= 0 )) stop("'x0' must be numeric > 0")
-    if (any(!is.numeric(t0) || !is.numeric(T))) stop(" 't0' and 'T' must be numeric")
-    if (any(!is.numeric(N)  || (N - floor(N) > 0) || N <= 1)) stop(" 'N' must be a positive integer ")
-    if (any(!is.numeric(M)  || (M - floor(M) > 0) || M <= 0)) stop(" 'M' must be a positive integer ")
-    if (any(!is.numeric(sigma) || sigma <= 0) ) stop(" 'sigma' must be a numeric > 0 ")
-    if (any(t0 < 0 || T < 0 || T <= t0) ) stop(" please use positive times! (0 <= t0 < T) ")
+    if (any(!is.numeric(x0) || x0 <= 0 )) 
+	    stop("'x0' must be numeric > 0")
+    if (any(!is.numeric(t0) || !is.numeric(T))) 
+	    stop(" 't0' and 'T' must be numeric")
+    if (any(!is.numeric(N)  || (N - floor(N) > 0) || N <= 1)) 
+	    stop(" 'N' must be a positive integer ")
+    if (any(!is.numeric(M)  || (M - floor(M) > 0) || M <= 0)) 
+	    stop(" 'M' must be a positive integer ")
+    if (any(!is.numeric(sigma) || sigma <= 0) ) 
+	    stop(" 'sigma' must be a numeric > 0 ")
+    if (any(t0 < 0 || T < 0 || T <= t0) ) 
+	        stop(" please use positive times! (0 <= t0 < T) ")
     if (is.null(Dt)) {
         Dt <- (T - t0)/N
         t <- seq(t0, T, by=Dt)
